Changelog — django-frontend-skeleton 0.5.0 documentation

### Navigation

- index
- previous |
- django-frontend-skeleton 0.5.0 documentation »

# Changelog

## 0.5.0

- Update to jQuery 1.9.1 (HTML5 Boilerplate)
- Update to Twitter Bootstrap 2.3.0 (Twitter Bootstrap)

## 0.4.0

- Update to jQuery 1.9.0 (HTML5 Boilerplate)
- Update to Normalize.css 1.1.0 (HTML5 Boilerplate)
- Update h5bp.css (HTML5 Boilerplate)
- Include changelog

## 0.3.0

- Namespace static files under ‘skeleton’
- Remove trailing slash from MANIFEST.in
- Documentation update/improvement

## 0.2.0

- Update to Twitter Bootstrap 2.2.2 (Twitter Bootstrap)
- Fix Glyphicons URL (Twitter Boostrap)
- Add documentation
- Minimize Readme

## 0.1.0

- Initial release

### Navigation

- index
- previous |
- django-frontend-skeleton 0.5.0 documentation »